@@ -336,7 +336,7 @@ class RobotConnection:
         None
         """
 
-        self.info.coordinates_are_inverted = True
+        self.info.coordinates_are_inverted = not self.info.coordinates_are_inverted
 
         self.info.gyroscope = Gyroscope(self.info, self.__info_dict)  # flip coordinates immediately
         self.info.lidar = LiDAR(self.info, self.__info_dict)
@@ -378,7 +378,7 @@ class RobotConnection:
         None
         """
         if self.info.coordinates_are_inverted:
-            bearing += -1
+            bearing *= -1
 
         self.__queue_event("SET steering " + tire_name + " " + str(bearing))
 
@@ -431,8 +431,15 @@ class RobotConnection:
                     tmp_dict = json.load(state_file)
                     self.__info_dict = tmp_dict
 
-                tmp_info = RobotInfo(self.__info_dict) # to prevent a race condition
-                self.info = tmp_info
+                if self.info:
+
+                    tmp_info = RobotInfo(self.__info_dict) # to prevent a race condition
+                    tmp_info.coordinates_are_inverted = self.info.coordinates_are_inverted
+                    self.info = tmp_info
+
+                else:
+
+                    self.info = RobotInfo(self.__info_dict)
 
             except (EnvironmentError, json.JSONDecodeError):
                 continue
